Package 'lecturenotes'

Title: My lecture notes Rmd template
Description: Template for exporting to both HTML and PDF formats. Takes care of various annoyances like missing affiliation headings for PDF, handling of non-standard fonts, correct parsing of interactive content depending on the output format, etc.
Authors: Grant McDermott [aut, cre] (ORCID: <https://orcid.org/0000-0001-7883-8573>)
Maintainer: Grant McDermott <[email protected]>
License: MIT + file LICENSE
Version: 0.2.2
Built: 2026-05-15 05:35:41 UTC
Source: https://github.com/grantmcdermott/lecturenotes

Help Index